pub struct ModulePluginRef {
pub manifest: Option<String>,
pub binary: Option<String>,
pub protocol: bool,
}Expand description
A reference to one plugin provided by the module. Exactly one of manifest
or binary must be set:
manifest— path (relative to the repo root) to aplugin.manifest.*(a manifest plugin, executed via argv dispatch).binary— path to an executable; withprotocol = trueit speaks the stdio plugin protocol, otherwise it is treated as a manifest-less binary.
Fields
manifest: Option<String>binary: Option<String>protocol: boolImplementations